\name{Divat}
\alias{Divat}
\docType{data}
\title{
Survival data extracted from the DIVAT cohort
}
\description{
Data were extracted from the DIVAT cohort. According to this data set, patient and graft survival can be computed for each hospital.
}
\usage{data(Divat)}
\format{
A data frame with the 3 following variables (columns).
  \describe{
    \item{\code{hospital}}{This numeric vector represents the hospital in which the kidney transplantation was performed. Six hospitals were included.}
	\item{\code{time}}{For right censored data, this numeric vector represents the follow up time (in days). When the event is observed, this numeric vector represents the exact time-to-event.}
    \item{\code{status}}{This indicator describes the end of the follow-up. The \code{status} equals 0 for right censored data and 1 if the event is observed.}
  }
}
\details{
The data were extracted from the prospective multicentric DIVAT cohort (www.divat.fr). Patients transplanted between 2000 and 2012 in 6 French centers were included. Only adult patients receiving a single kidney transplant and treated by Calcineurin inhibitors  and Mycophenolate Mofetil for maintenance therapy after transplantation were considered. In parallel, patients who received multi-organ transplantation were excluded from the study. 6,48 adult renal transplant recipients were included. The time-to-event under interest is the time between the kidney transplantation and the graft failure, i.e. the first event between the return in dialysis or the death of the patient with functional kidney.
}
\references{
Combescure C., Foucher Y. and Jackson D. The multivariate DerSimonian and Laird's methodology applied to meta-analysis of survival curves. Manuscript submitted.

Ladriere, M and Foucher, Y and Legendre, C and Kamar, N and Garrigue, V and Morelon, E and Kessler, M and Soulillou, JP and Giral M. The western europe cohort of kidney transplanted recipients - the DIVAT network. Clinical transplants; 2010:460-461.
}
\examples{

data(Divat)

divat.surv <- survfit(Surv(time/365.24, status) ~ hospital, data = Divat) 

plot(divat.surv, lty = 1:6, col=1:6, lwd=2, mark.time=FALSE,
 xlab="Post transplantation time (days)", ylab="Patient and graft survival") 

}

\keyword{datasets}

